@@ -24,11 +24,11 @@ See L<pip> for the front-end console application for this module.
 
 use 5.005;
 use strict;
-use Carp           ('croak');
+use Carp           'croak';
 use File::Spec     ();
 use File::Temp     ();
 use File::Basename ();
-use Params::Util   ('_STRING', '_CLASS', '_INSTANCE');
+use Params::Util   qw{ _STRING _CLASS _INSTANCE };
 use URI            ();
 use LWP::Simple    ();
 use CPAN::Inject   ();
@@ -36,7 +36,7 @@ use CPAN;
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.08';
+	$VERSION = '0.10';
 }
 
 
@@ -61,17 +61,25 @@ sub new {
 	$self->{p5i_dir}   = $self->_p5i_dir( $self->p5i_uri );
 	$self->{dir}       = File::Temp::tempdir( CLEANUP => 1 );
 
+	# Check the no_inject option
+	$self->{no_inject} = !! $self->{no_inject};
+
 	# Create the CPAN injector
-	$self->{inject} ||= CPAN::Inject->from_cpan_config;
-	unless ( _INSTANCE($self->{inject}, 'CPAN::Inject') ) {
-		Carp::croak("Did not provide a valid 'param' CPAN::Inject object");
+	unless ( $self->no_inject ) {
+		$self->{inject} ||= CPAN::Inject->from_cpan_config;
+		unless ( _INSTANCE($self->{inject}, 'CPAN::Inject') ) {
+			Carp::croak("Did not provide a valid 'param' CPAN::Inject object");
+		}
 	}
 
 	$self;
 }
 
+# Which params do we allow to read
+my %READ_ALLOW = ( no_inject => 1 );
+
 sub read {
-	my $class = shift;
+	my $class  = shift;
 
 	# Check the file
 	my $p5i = shift or croak( 'You did not specify a file name' );
@@ -79,6 +87,12 @@ sub read {
 	croak( "'$p5i' is a directory, not a file" )       unless -f _;
 	croak( "Insufficient permissions to read '$p5i'" ) unless -r _;
 
+	# Get a filtered set of params to pass through
+	my %params = @_;
+	   %params = map { $_ => $params{$_} }
+	             grep { $READ_ALLOW{$_} }
+	             sort keys %params;
+
 	# Slurp in the file
 	my $contents;
 	SCOPE: {
@@ -110,6 +124,7 @@ sub read {
 	return $header->new(
 		p5i   => $p5i,
 		lines => \@lines,
+		%params,
 		);
 }
 
@@ -141,6 +156,10 @@ sub dists {
 	%{ $_[0]->{dists} };
 }
 
+sub dists_hash {
+	$_[0]->{dists};
+}
+
 sub uris {
 	my $self = shift;
 	my %copy = %{ $self->{uris} };
@@ -150,10 +169,25 @@ sub uris {
 	%copy;
 }
 
+sub no_inject {
+	$_[0]->{no_inject};
+}
+
 sub inject {
 	$_[0]->{inject};
 }
 
+# Generate the plan file from the plan object
+sub as_string {
+	return join '',
+		map { "$_\n" }
+		$_[0]->can('ref')
+			? $_[0]->ref
+			: ref $_[0],
+		"",
+		$_[0]->lines;
+}
+
 
 
 
@@ -317,7 +351,7 @@ sub _p5i_dir {
 
 This module is stored in an Open Repository at the following address.
 
-L<http://svn.phase-n.com/svn/cpan/trunk/Module-Plan-Base>
+L<http://svn.ali.as/cpan/trunk/pip>
 
 Write access to the repository is made available automatically to any
 published CPAN author, and to most other volunteers on request.
@@ -335,7 +369,7 @@ If you cannot provide a direct test or fix, or don't have time to do so,
 then regular bug reports are still accepted and appreciated via the CPAN
 bug tracker.
 
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Module-Plan-Base>
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=pip>
 
 For other issues, for commercial enhancement and support, or to have your
 write access enabled for the repository, contact the author at the email
